@@ -1,6 +1,6 @@
 import math
 from collections import Counter
-from typing import Dict, Callable, List
+from typing import Dict, Callable, List, Tuple
 
 import numpy as np
 import timeit
@@ -43,6 +43,7 @@ def multilabel_classification_report(y_true, y_pred) -> pd.Series:
         'accuracy': M.accuracy_score(y_true, y_pred),
         'precision_macro': M.precision_score(y_true, y_pred, average='macro'),
         'recall_macro': M.recall_score(y_true, y_pred, average='macro'),
+        'f1_samples': M.f1_score(y_true, y_pred, average='samples'),
         'f1_macro': M.f1_score(y_true, y_pred, average='macro'),
         'f1_weighted': M.f1_score(y_true, y_pred, average='weighted'),
         'hamming_loss': M.hamming_loss(y_true, y_pred)
@@ -151,6 +152,30 @@ def jaccard(x, y) -> float:
     return len(s1 & s2) / len(s1 | s2)
 
 
+def outlier_cutoff(values: List) -> Tuple[float, float]:
+    """
+    Generate the lower and upper bound for outliers.
+
+    Extra:
+    ```
+    Lower bound: < Q1 - 1.5 * IQR
+    Upper bound: > Q3 + 1.5 * IQR
+    ```
+
+    Args:
+        values: List of numerical values
+
+    Returns:
+        Tuple of (lower-cutoff, upper-cutoff)
+    """
+    q1 = np.quantile(values, 0.25)
+    q3 = np.quantile(values, 0.75)
+    iqr = q3 - q1
+    lower_threshold = q1 - 1.5 * iqr
+    upper_threshold = q3 + 1.5 * iqr
+    return lower_threshold, upper_threshold
+
+
 def sorted_classification_report(y_true, y_pred, **kwargs) -> pd.DataFrame:
     """
     Generate class-wise classification report sorted from worst to best.
